@@ -22,10 +22,6 @@ import importlib
 import sys
 
 
-
-
-
-
 try:
     import uvloop
     asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())
@@ -586,4 +582,4 @@ class Spider(SpiderHook):
         """
         self.logger.info(f"Asyncpy finished spider: {self.name}")
         await self._cancel_tasks()
-        self.loop.stop()
\ No newline at end of file
+        #self.loop.stop()
\ No newline at end of file
