@@ -2,12 +2,12 @@
 
 
 from asyncpy.spider import Spider
-
+import settings
 
 
 class DemoSpider(Spider):
     name = 'templates'
-
+    settings_attr = settings
 
     start_urls = []
 
